<?php

class EventsManager_category extends AireDbObject
{
	protected $table = 'events_categories';
	
	protected $custom_fields = array(
		'name'=>'',
		'description'=>''
		);
}

?>